@@ -1,12 +1,10 @@
-#' convert a dfm to a non-quanteda format
+#' Convert a dfm to a non-quanteda format
 #' 
 #' Convert a quanteda \link{dfm} object to a format useable by other text
 #' analysis packages.  The general function \code{convert} provides easy
 #' conversion from a dfm to the document-term representations used in all other
-#' text analysis packages for which conversions are defined.    See also
-#' \link{convert-wrappers} for convenience functions for specific package
-#' converters.
-#' @param x dfm to be converted
+#' text analysis packages for which conversions are defined.
+#' @param x a \link{dfm} to be converted
 #' @param to target conversion format, consisting of the name of the package 
 #'   into whose document-term matrix representation the dfm will be converted: 
 #'   \describe{ \item{\code{"lda"}}{a list with components "documents" and 
@@ -19,16 +17,12 @@
 #'   \item{\code{"lsa"}}{the "textmatrix" format as 
 #'   used by the \pkg{lsa} package} }
 #' @param docvars optional data.frame of document variables used as the
-#'   \code{meta} information in conversion to the STM package format.  This aids
-#'   in selecting the document variables only corresponding to the documents
-#'   with non-zero counts.
-#' @param ... unused
+#'   \code{meta} information in conversion to the \pkg{stm} package format.
+#'   This aids in selecting the document variables only corresponding to the
+#'   documents with non-zero counts.
 #' @return A converted object determined by the value of \code{to} (see above). 
 #'   See conversion target package documentation for more detailed descriptions 
 #'   of the return formats.
-#' @note There also exist a variety of converter shortcut commands, designed to 
-#' mimic the idioms of the packages into whose format they convert.  
-#' See \link{convert-wrappers} for details.
 #' @export
 #' @examples
 #' mycorpus <- corpus_subset(data_corpus_inaugural, Year > 1970)
@@ -58,38 +52,46 @@
 #' ldadfm <- convert(quantdfm, to = "lda")
 #' str(ldadfm)
 #' }
-convert <- function(x, to = c("lda", "tm", "stm", "austin", "topicmodels", "lsa",
-                         "matrix", "data.frame"), docvars = NULL, ...) {
+convert <- function(x, to = c("lda", "tm", "stm", "austin", "topicmodels", 
+                              "lsa", "matrix", "data.frame"), docvars = NULL) {
     UseMethod("convert")
 }
 
+#' @export
+convert.default <- function(x, ...) {
+    stop(friendly_class_undefined_message(class(x), "convert"))
+}
+
 #' @noRd
 #' @export
-convert.dfm <- function(x, to = c("lda", "tm", "stm", "austin", "topicmodels", "lsa",
-                                  "matrix", "data.frame"), docvars = NULL, ...) {
-    
+convert.dfm <- function(x, to = c("lda", "tm", "stm", "austin", "topicmodels", 
+                                  "lsa", "matrix", "data.frame"), 
+                        docvars = NULL) {
     x <- as.dfm(x)
     to <- match.arg(to)
-    if (length(addedArgs <- list(...)))
-        warning("Argument", if (length(addedArgs) > 1L) "s " else " ", names(addedArgs), " not used.", sep = "")
-    
+
     if (!is.null(docvars)) {
-        if (!is.data.frame(docvars))
+        if (!is.data.frame(docvars)) 
             stop("docvars must be a data.frame")
         if (nrow(docvars) != ndoc(x))
             stop("docvars must have the same number of rows as ndoc(x)")
     }
     
+    if ((to %in% c("stm", "lda", "topicmodels")) &&
+        (x@weightTf$scheme != "count" || x@weightDf$scheme != "unary")) {
+        stop("cannot convert a non-count dfm to a topic model format")
+    }
+    
     if (to == "tm") 
-        return(dfm2tmformat(x, ...))
+        return(dfm2tm(x))
     else if (to == "lda")
-        return(dfm2ldaformat(x))
+        return(dfm2lda(x))
     else if (to == "stm")
-        return(dfm2stmformat(x, docvars))
+        return(dfm2stm(x, docvars))
     else if (to == "austin")
-        return(dfm2austinformat(x))
+        return(dfm2austin(x))
     else if (to == "topicmodels")
-        return(quantedaformat2dtm(x))
+        return(dfm2dtm(x))
     else if (to == "lsa")
         return(dfm2lsa(x))
     else if (to == "data.frame")
@@ -102,7 +104,7 @@ convert.dfm <- function(x, to = c("lda", "tm", "stm", "austin", "topicmodels", "
 }
 
 
-#' convenience wrappers for dfm convert
+#' Convenience wrappers for dfm convert
 #' 
 #' To make the usage as consistent as possible with other packages, quanteda
 #' also provides shortcut wrappers to \code{\link{convert}}, designed to be
@@ -144,26 +146,7 @@ as.wfm <- function(x) {
 #' @method as.wfm dfm
 #' @export
 as.wfm.dfm <- function(x) {
-    x <- as.dfm(x)
-    convert(x, to = "austin")
-}
-
-dfm2austinformat <- function(d) {
-    d <- as.matrix(as(d, 'dgeMatrix'))
-    names(dimnames(d))[2] <- "words"
-    class(d) <- c("wfm", "matrix")
-    d
-}
-
-## convert to tm format
-dfm2tmformat <- function(x, weighting = tm::weightTf) {
-    if (!requireNamespace("tm", quietly = TRUE)) 
-        stop("You must install the tm package installed for this conversion.")
-    if (!requireNamespace("slam", quietly = TRUE))
-        stop("You must install the slam package installed for this conversion.")
-    sl <- slam::as.simple_triplet_matrix(x)
-    td <- tm::as.DocumentTermMatrix(sl, weighting = weighting)
-    return(td)
+    convert(as.dfm(x), to = "austin")
 }
 
 #' @export
@@ -183,142 +166,154 @@ dfm2tmformat <- function(x, weighting = tm::weightTf) {
 #' identical(as.DocumentTermMatrix(quantdfm), convert(quantdfm, to = "tm"))
 #' }
 #' 
-as.DocumentTermMatrix <- function(x, ...) {
+as.DocumentTermMatrix <- function(x) {
     UseMethod("as.DocumentTermMatrix")
 }
 
 #' @noRd
 #' @method as.DocumentTermMatrix dfm
 #' @export
-as.DocumentTermMatrix.dfm <- function(x, ...) {
-    x <- as.dfm(x)
-    convert(x, to = "tm", ...)
+as.DocumentTermMatrix.dfm <- function(x) {
+    convert(as.dfm(x), to = "tm")
 }
 
+#' @keywords internal
+dfm2austin <- function(x) {
+    result <- as.matrix(as(x, 'dgeMatrix'))
+    names(dimnames(result))[2] <- "words"
+    class(result) <- c("wfm", "matrix")
+    result
+}
+
+#' @keywords internal
+dfm2tm <- function(x, weighting = tm::weightTf) {
+    if (!requireNamespace("tm", quietly = TRUE)) 
+        stop("You must install the tm package installed for this conversion.")
+    if (!requireNamespace("slam", quietly = TRUE))
+        stop("You must install the slam package installed for this conversion.")
+    
+    if (!(x@weightTf$scheme == "count" && x@weightDf$scheme == "unary")) {
+        warning("converted DocumentTermMatrix will not have weight attributes set correctly")
+    }
+    tm::as.DocumentTermMatrix(slam::as.simple_triplet_matrix(x),
+                              weighting = weighting)
+}
+
+## TODO: 
+## Implement weight recordings for 
+## weightTfIdf
+## - attr(*, "weighting")= chr [1:2] "term frequency - inverse document frequency" "tf-idf"
+## - attr(*, "weighting")= chr [1:2] "term frequency - inverse document frequency (normalized)" "tf-idf"
+## weightTf
+## - attr(*, "weighting")= chr [1:2] "term frequency" "tf"
+## weightSMART
+## - attr(*, "weighting")= chr [1:2] "SMART ntc" "SMART"  (e.g.)
+
+
 #' @rdname convert-wrappers
 #' @details
-#' \code{dfm2ldaformat} provides converts a \link{dfm} into the list representation
+#' \code{dfm2lda} provides converts a \link{dfm} into the list representation
 #' of terms in documents used by the \pkg{lda} package (a list with components 
 #' "documents" and "vocab" as needed by 
 #'   \code{\link[lda]{lda.collapsed.gibbs.sampler}}).
-#' @export
+#' @examples
+#' \dontrun{
+#' # shortcut conversion to lda package list format
+#' identical(dfm2lda(quantdfm), convert(quantdfm, to = "lda")) 
+#' }
+#' 
+#' @keywords internal
+dfm2lda <- function(x) {
+    x <- as.dfm(x)
+    if (!requireNamespace("tm", quietly = TRUE))
+        stop("You must install the slam package installed for this conversion.")
+    dtm2lda(dfm2dtm(x))
+}
+
+#' @noRd
+#' @details
+#' \code{dfm2ldaformat} provides converts a \link{dfm} into the list
+#' representation of terms in documents used by the \pkg{lda} package (a list
+#' with components "documents" and "vocab" as needed by
+#' \code{\link[lda]{lda.collapsed.gibbs.sampler}}).
 #' @examples
 #' \dontrun{
 #' # shortcut conversion to lda package list format
 #' identical(dfm2ldaformat(quantdfm), convert(quantdfm, to = "lda")) 
 #' }
-#' 
-dfm2ldaformat <- function(x) {
-    UseMethod("dfm2ldaformat")
-}
-
-#' @noRd
-#' @export
-dfm2ldaformat.dfm <- function(x) {
-    x <- as.dfm(x)
-    if (!requireNamespace("tm", quietly = TRUE))
-        stop("You must install the slam package installed for this conversion.")
-    tmDTM <- dfm2tmformat(x)
-    return(dtm2ldaformat(tmDTM))
-}
-
-
-## from the package topicmodels
-dtm2ldaformat <- function (x, omit_empty = TRUE) {
+#' @keywords internal
+dtm2lda <- function (x, omit_empty = TRUE) {
     if (!requireNamespace("slam", quietly = TRUE))
         stop("You must install the slam package installed for this conversion.")
     
-    split.matrix <- function(x, f, drop = FALSE, ...) lapply(split(seq_len(ncol(x)), 
-                                                                   f, drop = drop, ...), function(ind) x[, ind, drop = FALSE])
-    documents <- vector(mode = "list", length = nrow(x))
-    names(documents) <- rownames(x)
-    documents[slam::row_sums(x) > 0] <- split(rbind(as.integer(x$j) - 
-                                                        1L, as.integer(x$v)), as.integer(x$i))
+    docs <- vector(mode = "list", length = nrow(x))
+    names(docs) <- rownames(x)
+
+    docs[slam::row_sums(x) > 0] <- split.matrix(rbind(as.integer(x$j) - 1L, 
+                                                      as.integer(x$v)), 
+                                                as.integer(x$i))
     if (omit_empty) 
-        documents[slam::row_sums(x) == 0] <- NULL
-    else documents[slam::row_sums(x) == 0] <- rep(list(matrix(integer(), 
-                                                              ncol = 0, nrow = 2)), sum(slam::row_sums(x) == 0))
-    list(documents = documents, vocab = colnames(x))
+        docs[slam::row_sums(x) == 0] <- NULL
+    else docs[slam::row_sums(x) == 0] <- rep(list(matrix(integer(), 
+                                                         ncol = 0, nrow = 2)), 
+                                             sum(slam::row_sums(x) == 0))
+    list(documents = docs, vocab = colnames(x))
 }
 
-#' @rdname convert-wrappers
-#' @export
-#' @details \code{quantedaformat2dtm} provides converts a \link{dfm} into the
-#' sparse simple triplet matrix representation of terms in documents used by the
-#' \pkg{topicmodels} package.
-#' @examples 
-#' # shortcut conversion to topicmodels package format
-#' \dontrun{
-#' identical(quantedaformat2dtm(quantdfm), 
-#'           convert(quantdfm, to = "topicmodels")) 
-#' }
-#' 
-quantedaformat2dtm <- function(x) {
-    UseMethod("quantedaformat2dtm")
+# internal function for dtm2lda
+split.matrix <- function(x, f, drop = FALSE, ...) {
+    lapply(split(seq_len(ncol(x)), 
+                 f, drop = drop, ...), function(ind) x[, ind, drop = FALSE])
 }
 
-#' @noRd
-#' @export
-quantedaformat2dtm.dfm <- function(x) {
-    x <- as.dfm(x)
-    d_lda <- convert(x, to = "lda")
-    ldaformat2dtm(d_lda$documents, d_lda$vocab)
-}
+#' @keywords internal
+dfm2dtm <- function(x, omit_empty = TRUE) {
 
-ldaformat2dtm <- function (documents, vocab, omit_empty = TRUE) {
     if (!requireNamespace("tm", quietly = TRUE))
         stop("You must install the tm package installed for this conversion.")
     if (!requireNamespace("slam", quietly = TRUE))
         stop("You must install the slam package installed for this conversion.")
     
-    stm <- slam::simple_triplet_matrix(i = rep(seq_along(documents), vapply(documents, ncol, integer(1))), 
-                                       j = as.integer(unlist(lapply(documents, "[", 1, )) + 1L),
-                                       v = as.integer(unlist(lapply(documents, "[", 2, ))), nrow = length(documents), ncol = length(vocab),
-                                       dimnames = list(names(documents), vocab))
-    dtm <- tm::as.DocumentTermMatrix(stm, tm::weightTf)
+    x <- as.dfm(x)
+    x <- as(x, 'dgTMatrix')
     if (omit_empty) 
-        dtm <- dtm[slam::row_sums(dtm) > 0, ]
-    dtm
+        x <- x[rowSums(x) > 0, ]
+    tm::as.DocumentTermMatrix(slam::as.simple_triplet_matrix(x), tm::weightTf)
 }
 
-dfm2stmformat <- function(data, meta) {
+
+#' @keywords internal
+dfm2stm <- function(x, docvars, omit_empty = TRUE) {
     # get docvars (if any)
-    dvars <- docvars(data)
+    if (is.null(docvars))
+        docvars <- docvars(x)
     
     # sort features into alphabetical order
-    data <- data[, order(featnames(data))]
-    data <- as(data, "dgTMatrix")
-    
-    # find out which documents are not empty
-    non_empty_docs <- which(rowSums(data) != 0)
-    non_empty_feats <- which(colSums(data) != 0)
-    
-    # find out which documents are empty
-    empty_docs <- which(rowSums(data) == 0)
-    if (length(empty_docs) > 0) warning("Dropped empty document(s): ", paste0(names(empty_docs), collapse=", "))
-    
-    # find out which feature are empty across all documents
-    empty_feats <- which(colSums(data) == 0)
-    if (length(empty_feats) > 0) warning("zero-count features: ", paste0(names(empty_feats), collapse=", "))
-    
-    # convert counts to STM documents format
-    documents <- ijv.to.doc(data[non_empty_docs, non_empty_feats]@i+1, data[non_empty_docs, non_empty_feats]@j+1, data[non_empty_docs, non_empty_feats]@x) 
-    names(documents) <- rownames(data)[non_empty_docs]
-    
-    # select docvars for non-empty docs or from dfm
-    # meta takes priority over built-in docvars
-    if (!is.null(meta)) {
-        meta <- meta[non_empty_docs, , drop = FALSE]
-    } else if (length(dvars)) {
-        meta <- dvars[non_empty_docs, , drop = FALSE]
+    x <- x[, order(featnames(x))]
+    if (omit_empty) {
+        
+        empty_docs <- rowSums(x) == 0
+        if (sum(empty_docs) > 0) 
+            warning("Dropped empty document(s): ", 
+                    paste0(docnames(x)[empty_docs], collapse = ", "))
+        
+        empty_feats <- colSums(x) == 0
+        if (sum(empty_feats) > 0) 
+            warning("zero-count features: ", 
+                    paste0(featnames(x)[empty_feats], collapse = ", "))
+        
+        x <- x[!empty_docs, !empty_feats]
+        docvars <- docvars[!empty_docs,, drop = FALSE]
     }
     
-    # return the object
-    list(documents = documents, vocab = colnames(data)[non_empty_feats], meta = meta)
+    # convert counts to STM documents format
+    x <- as(x, "dgTMatrix")
+    docs <- ijv.to.doc(x@i + 1, x@j + 1, x@x) 
+    names(docs) <- rownames(x)
+    list(documents = docs, vocab = colnames(x), meta = docvars)
 }
 
-
-# borrowed from the STM package
+# internal function for dfm2stm
 ijv.to.doc <- function(i, j, v) {
     index <- split(j, i)
     index <- lapply(index, as.integer)
@@ -327,23 +322,21 @@ ijv.to.doc <- function(i, j, v) {
     mapply(rbind, index, count, SIMPLIFY = FALSE)
 }
 
-#' convert a dfm to an lsa "textmatrix"
+#' Convert a dfm to an lsa "textmatrix"
 #' 
 #' Converts a dfm to a textmatrix for use with the lsa package.
 #' @param x dfm to be converted
 #' @examples
 #' \dontrun{
-#' (mydfm <- dfm(c(d1 = "this is a first matrix", d2 = "this is second matrix as example")))
+#' (mydfm <- dfm(c(d1 = "this is a first matrix", 
+#'                 d2 = "this is second matrix as example")))
 #' lsa::lsa(convert(mydfm, to = "lsa"))
 #' }
 #' @keywords internal
 dfm2lsa <- function(x) {
     x <- as.matrix(x)
-    # convert to integer
-    x <- apply(x, c(1,2), as.integer)
-    class(x) <- "textmatrix"
-    names(dimnames(x)) <- c("docs", "terms") 
-    t(x)
+    result <- apply(x, c(1,2), as.integer) # convert to integer
+    names(dimnames(result)) <- c("docs", "terms") 
+    class(result) <- "textmatrix"
+    t(result)
 }
-    
-
