@@ -1,7 +1,6 @@
-#' a paragraph of text for testing various text-based functions
+#' A paragraph of text for testing various text-based functions
 #' 
 #' This is a long paragraph (2,914 characters) of text taken from a debate on
-#' the Irish budget in \emph{Dáil Éireann} by Socialist \emph{Teachta Dála} (TD)
 #' Joe Higgins, delivered December 8, 2011.
 #' @format character vector with one element
 #' @keywords data
@@ -12,7 +11,7 @@
 #' tokens(data_char_sampletext, remove_punct = TRUE)
 "data_char_sampletext"
 
-#' immigration-related sections of 2010 UK party manifestos
+#' Immigration-related sections of 2010 UK party manifestos
 #' 
 #' Extracts from the election manifestos of 9 UK political parties from 2010, related
 #' to immigration or asylum-seekers.
@@ -75,7 +74,7 @@
 # save(data_corpus_irishbudget2010, file="data/data_corpus_irishbudget2010.RData")
 
 
-#' internal data sets
+#' Internal data sets
 #' 
 #' Data sets used for mainly internal purposes by the \pkg{quanteda} package.
 #' @name data-internal
@@ -165,4 +164,42 @@ NULL
 #' kwic(data_char_ukimmig2010, "not")
 "data_dictionary_LSD2015"
 
+#' Confidence debate from 1991 Irish Parliament
+#' 
+#' Texts of speeches from a no-confidence motion debated in the Irish Dáil in
+#' October 1991 over the future of the Fianna Fail-Progressive Democrat
+#' coalition.  (See Laver and Benoit 2002 for details.)
+#' @format \code{data_corpus_dailnoconf1991} is a corpus with 58 texts, 
+#'   including docvars for \code{name}, \code{party}, and \code{position}.
+#' @references Laver, Michael, and Kenneth Benoit. 2002. 
+#'   "\href{http://www.kenbenoit.net/pdfs/Laver_Benoit_IPS_2002.pdf}{Locating 
+#'   TDs in Policy Spaces: Wordscoring Dáil Speeches}." \emph{Irish Political 
+#'   Studies} 17 (Summer): 59-73.
+#'   
+#'   Laver, Michael, Kenneth Benoit, and John Garry. 2003. 
+#'   "\href{http://www.kenbenoit.net/pdfs/WORDSCORESAPSR.pdf}{Estimating policy 
+#'   positions from political text using words as data.}" \emph{American 
+#'   Political Science Review} 97(2): 311-331.
+#' @keywords data
+#' @examples
+#' \dontrun{
+#' data_dfm_dailnoconf1991 <- dfm(data_corpus_dailnoconf1991, removePunct = TRUE)
+#' fitted <- textmodel_mixfit(data_dfm_dailnoconf1991, 
+#'                            c("Govt", "Opp", "Opp", rep(NA, 55)))
+#' (pred <- predict(fitted))
+#' tmpdf <- 
+#'     data.frame(party = as.character(docvars(data_corpus_dailnoconf1991, "party")),
+#'                govt = coef(pred)[,"Govt"],
+#'                position = as.character(docvars(data_corpus_dailnoconf1991, "position")),
+#'                stringsAsFactors = FALSE)
+#' bymedian <- with(tmpdf, reorder(paste(party, position), govt, median))
+#' par(mar = c(5, 6, 4, 2)+.1)
+#' boxplot(govt ~ bymedian, data = tmpdf,
+#'         horizontal = TRUE, las = 1,
+#'         xlab = "Degree of support for government")
+#' abline(h = 7.5, col = "red", lty = "dashed")
+#' text(c(0.9, 0.9), c(8.5, 6.5), c("Goverment", "Opposition"))
+#' }
+"data_corpus_dailnoconf1991"
+
 
