@@ -1,4 +1,4 @@
-#' recombine a dfm or fcm by combining identical dimension elements
+#' Recombine a dfm or fcm by combining identical dimension elements
 #' 
 #' "Compresses" or groups a \link{dfm} or \link{fcm} whose dimension names are
 #' the same, for either documents or features.  This may happen, for instance,
@@ -36,11 +36,17 @@ dfm_compress <- function(x, margin = c("both", "documents", "features")) {
     UseMethod("dfm_compress")
 }
     
-#' @noRd
+#' @export
+dfm_compress.default <- function(x, 
+                                 margin = c("both", "documents", "features")) {
+    stop(friendly_class_undefined_message(class(x), "dfm_compress"))
+}
+
 #' @export
 dfm_compress.dfm <- function(x, margin = c("both", "documents", "features")) {
     
     x <- as.dfm(x)
+    if (!nfeat(x) || !ndoc(x)) return(x)
     margin <- match.arg(margin)
     if (margin == 'documents') {
         result <- group_dfm(x, NULL, docnames(x))
@@ -52,47 +58,3 @@ dfm_compress.dfm <- function(x, margin = c("both", "documents", "features")) {
     return(result)
 }
 
-#' sort a dfm by frequency of one or more margins
-#' 
-#' Sorts a \link{dfm} by descending frequency of total features, total features
-#' in documents, or both.
-#' 
-#' @param x Document-feature matrix created by \code{\link{dfm}}
-#' @param margin which margin to sort on \code{features} to sort by frequency of
-#'   features, \code{documents} to sort by total feature counts in documents,
-#'   and \code{both} to sort by both
-#' @param decreasing logical; if \code{TRUE}, the sort will be in descending order,
-#'   otherwise sort in increasing order
-#' @return A sorted \link{dfm} matrix object
-#' @export
-#' @author Ken Benoit
-#' @examples
-#' dtm <- dfm(data_corpus_inaugural)
-#' head(dtm)
-#' head(dfm_sort(dtm))
-#' head(dfm_sort(dtm, decreasing = FALSE, "both"))
-dfm_sort <- function(x, decreasing = TRUE, 
-                     margin = c("features", "documents", "both")) {
-    UseMethod("dfm_sort")
-}
-
-#' @noRd
-#' @export
-dfm_sort.dfm <- function(x, decreasing = TRUE, 
-                         margin = c("features", "documents", "both")) {
-    
-    x <- as.dfm(x)
-    margin <- match.arg(margin)
-    class_org <- class(x)
-    if (margin=="features") {
-        x <- x[, order(colSums(x), decreasing=decreasing)]
-    } else if (margin=="documents") {
-        x <- x[order(rowSums(x), decreasing=decreasing), ]
-    } else if (margin=="both") {
-        x <- x[order(rowSums(x), decreasing=decreasing),
-               order(colSums(x), decreasing=decreasing)]
-    }
-    class(x) <- class_org
-    return(x)
-}
-
