@@ -31,30 +31,30 @@
 #' @keywords dfm
 #' @seealso dfm_replace
 #' @examples
-#' myDict <- dictionary(list(christmas = c("Christmas", "Santa", "holiday"),
+#' my_dict <- dictionary(list(christmas = c("Christmas", "Santa", "holiday"),
 #'                           opposition = c("Opposition", "reject", "notincorpus"),
 #'                           taxglob = "tax*",
 #'                           taxregex = "tax.+$",
 #'                           country = c("United_States", "Sweden")))
-#' myDfm <- dfm(c("My Christmas was ruined by your opposition tax plan.", 
+#' my_dfm <- dfm(c("My Christmas was ruined by your opposition tax plan.", 
 #'                "Does the United_States or Sweden have more progressive taxation?"),
 #'              remove = stopwords("english"), verbose = FALSE)
-#' myDfm
+#' my_dfm
 #' 
 #' # glob format
-#' dfm_lookup(myDfm, myDict, valuetype = "glob")
-#' dfm_lookup(myDfm, myDict, valuetype = "glob", case_insensitive = FALSE)
+#' dfm_lookup(my_dfm, my_dict, valuetype = "glob")
+#' dfm_lookup(my_dfm, my_dict, valuetype = "glob", case_insensitive = FALSE)
 #' 
 #' # regex v. glob format: note that "united_states" is a regex match for "tax*"
-#' dfm_lookup(myDfm, myDict, valuetype = "glob")
-#' dfm_lookup(myDfm, myDict, valuetype = "regex", case_insensitive = TRUE)
+#' dfm_lookup(my_dfm, my_dict, valuetype = "glob")
+#' dfm_lookup(my_dfm, my_dict, valuetype = "regex", case_insensitive = TRUE)
 #' 
 #' # fixed format: no pattern matching
-#' dfm_lookup(myDfm, myDict, valuetype = "fixed")
-#' dfm_lookup(myDfm, myDict, valuetype = "fixed", case_insensitive = FALSE)
+#' dfm_lookup(my_dfm, my_dict, valuetype = "fixed")
+#' dfm_lookup(my_dfm, my_dict, valuetype = "fixed", case_insensitive = FALSE)
 #' 
 #' # show unmatched tokens
-#' dfm_lookup(myDfm, myDict, nomatch = "_UNMATCHED")
+#' dfm_lookup(my_dfm, my_dict, nomatch = "_UNMATCHED")
 #' 
 dfm_lookup <- function(x, dictionary, levels = 1:5,
                        exclusive = TRUE, 
@@ -110,7 +110,7 @@ dfm_lookup.dfm <- function(x, dictionary, levels = 1:5,
     for (h in seq_along(dictionary)) {
         values <- as.list(stri_replace_all_fixed(dictionary[[h]], ' ', 
                                                  attr(x, 'concatenator')))
-        values_temp <- unlist(regex2id(values, index = index))
+        values_temp <- unlist(pattern2id(values, index = index))
         values_id <- c(values_id, values_temp)
         keys_id <- c(keys_id, rep(h, length(values_temp)))
     }
