@@ -62,7 +62,7 @@ dfm_subset.dfm <- function(x, subset, select, ...) {
         if (is.dfm(r)) {
             if (!missing(select)) stop("cannot select docvars if subset is a dfm")
             x <- x[which(docnames(x) %in% docnames(r)), ]
-            return(dfm_group(dfm_trim(x, min_count = 1, min_docfreq = 1, 
+            return(dfm_group(dfm_trim(x, min_termfreq = 1, min_docfreq = 1, 
                                       verbose = FALSE), 
                              groups = factor(docnames(x), levels = docnames(r)),
                              fill = TRUE))
