@@ -1,4 +1,5 @@
-context('test textstat_simil.R')
+context("test textstat_simil.R")
+
 # correlation
 test_that("test textstat_simil method = \"correlation\" against proxy simil(): documents", {
     skip_if_not_installed("proxy")
@@ -309,20 +310,20 @@ test_that("textstat_simil stops as expected for methods not supported",{
     "Yule is not implemented; consider trying proxy::simil\\(\\)")
 })
 
-test_that("textstat_simil stops as expected for wrong selections",{
-    presDfm <- dfm(corpus_subset(data_corpus_inaugural, Year > 1980), remove = stopwords("english"),
-                   stem = TRUE, verbose = FALSE)
-    expect_error(textstat_simil(presDfm, 5), 
-                 "The vector/matrix specified by 'selection' must be conform to the object x in columns")
-    expect_error(textstat_simil(presDfm, 5, margin = "features"), 
-                 "The vector/matrix specified by 'selection' must be conform to the object x in rows")
-    
-    expect_error(textstat_simil(presDfm, margin = "documents", "2009-Obamaa"), 
-                 "The documents specified by 'selection' do not exist.")
-    expect_error(textstat_simil(presDfm, margin = "features", "Obamaa"), 
-                 "The features specified by 'selection' do not exist.")
-    
-})
+# test_that("textstat_simil stops as expected for wrong selections",{
+#     presDfm <- dfm(corpus_subset(data_corpus_inaugural, Year > 1980), remove = stopwords("english"),
+#                    stem = TRUE, verbose = FALSE)
+#     expect_error(textstat_simil(presDfm, selection = 5), 
+#                  "The vector/matrix specified by 'selection' must be conform to the object x in columns")
+#     expect_error(textstat_simil(presDfm, selection = 5, margin = "features"), 
+#                  "The vector/matrix specified by 'selection' must be conform to the object x in rows")
+#     
+#     expect_error(textstat_simil(presDfm, margin = "documents", selection = "2009-Obamaa"), 
+#                  "The documents specified by 'selection' do not exist.")
+#     expect_error(textstat_simil(presDfm, margin = "features", selection = "Obamaa"), 
+#                  "The features specified by 'selection' do not exist.")
+#     
+# })
 
 # test_that("test textstat_simil works as expected for 'n' is not NULL", {
 #     skip_if_not_installed("proxy")
